# pov Library


### Core library of [pov](https://pypi.org/project/pov/)
Pyrogram And Telethon based for your userbot.


### Installing

``` bash
pip3 install pov
```

### License
[![License](https://www.gnu.org/graphics/gplv3-with-text-136x68.png)](LICENSE)   
This library is licensed under [GNU General Public License](https://www.gnu.org/licenses/agpl-3.0.html) v3 or later.

# Credits
*  [???](https://pypi.org/project/pov/) for [pov](https://pypi.org/project/pov/)
*  [Dan](https://github.com/delivrance) for [Pyrogram](https://github.com/pyrogram/pyrogram)
*  [Lonami](https://github.com/LonamiWebs/) for [Telethon](https://github.com/LonamiWebs/Telethon)
